'use strict'
/**
 *
 *  @class OneLineのメインとなるクラス。
 *  @classdesc OneLine Main
 *
 */
var OneLine = function () {
    this.result;
    /**
     * Policyクラスのインスタンスです。
     * @property {Policy}
     */
    this.policy;
    /**
     * OneLineFormクラスのインスタンス
     * @property {OneLineForm}
     */
    this.oneline_form;
    /**
     * NeedleWork本体へ投げるリクエストのURLです。
     * @property {string}
     */
    this.requestUrl;
    /**
     * 試験を開始する関数
     */
    OneLine.prototype.Start = function () {
        this.policy = new Policy();
        this.result = new OneLineResult();
        this.oneline_form = new OneLineForm();
        this.policy["test_type"] = "oneline";
        this.policy.setDOMData();
        this.policy.Validate();
        this.oneline_form.Disable();
        if (!this.policy.isInvalid) {//バリデーションエラーがない場合
            var that = this;
            this.policy.BuildURL();
            setTimeout(function () {
                that.policy.Send().then(
                    function (data) {
                        that.Success(data);
                    }, function (xhr) {
                        that.Error(xhr);
                    });
            }, 250);
        } else {//バリデーションエラーがある場合
            this.oneline_form.StopSpinner();
            this.oneline_form.ShowError(this.policy.getMessage());
            this.oneline_form.Enable();
        }
    }
    /**
     * データを送信する関数
     * @return {string} 通信結果
     */
    OneLine.prototype.Send = function () {
        console.info("*Sending Data...")
        return $.ajax({
            type: 'GET',
            url: this.requestUrl,
            dataType: 'json',
            timeout: 30000,
        })
    }
    /**
     * 通信成功時の関数
     */
    OneLine.prototype.Success = function (data) {
        console.info("Success");
        if (data.Result == 0) {
            this.result.SetResultStatus('success', 'check', 'Pass');
        } else if (data.Result == 1) {
            this.result.SetResultStatus('warning', 'ban', 'Drop');
        } else {
            this.result.SetResultStatus('error', 'warning', 'Error');
            this.result.ErrorMessage(data.EString);
        }
        this.result.BuildHTML(this.policy.field);
        this.result.Show();
        this.oneline_form.StopSpinner();
        this.oneline_form.Enable();
    }
    /**
     * 通信失敗時の関数
     */
    OneLine.prototype.Error = function (xhr) {
        console.info("Error");
        var message = "";
        this.result.SetResultStatus('error', 'warning', 'Error');
        if (xhr.responseJSON !== undefined) {
            message += xhr.responseJSON.Message;
        } else {
            message += 'Unreachable';
        }
        message += '</div></div>';
        this.result.ErrorMessage(message);
        this.result.BuildHTML(this.policy.field);
        this.result.Show();
        this.oneline_form.StopSpinner();
        this.oneline_form.Enable();
    }
}

/**
 *  @class onelineのテスト結果を操作する用のクラスです。
 */
var OneLineResult = function () {
    /**
     * @type {string}
     */
    this.alert_level = "";
    /**
     * @type {string}
     */
    this.result_status = "";
    /**
     * @type {string}
     */
    this.display_alert_level = "";
    /**
     * @type {string}
     */
    this.message = "";
    /**
     * 通信エラーの内容
     * @type {string}
     */
    this.error_msg = "";
    /**
     * 通信がエラーがるかのフラグ
     * @type {string}
     */
    this.isError = false;
    OneLineResult.prototype.SetResultStatus = function (alert_level, display_alert_level, result_status) {
        this.alert_level = alert_level;
        this.display_alert_level = display_alert_level;
        this.result_status = result_status;
    }
    OneLineResult.prototype.ErrorMessage = function (msg) {
        this.error_msg += msg;
        this.isError = true;
    }
    OneLineResult.prototype.BuildHTML = function (field) {
        console.info("*Building Message...");
        let txt = "";
        txt = '<div class="col-md-12">';
        txt += '<div class="alert alert-' + this.alert_level + ' alert-dismissible">';
        txt += '<button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>';
        txt += '<h4><i class="icon fa fa-' + this.display_alert_level + '"></i> ' + this.result_status + '';
        txt += ' <small style="color:#fff;">at ';
        txt += getNow();
        txt += '</small></h4>';
        if (this.isError) { //エラーの場合の結果
            txt += this.error_msg;
        } else {//正常な場合の結果
            txt += '<span class="label">' + field["protocol"].getValue() + '</span> ';
            txt += field["src_ip"].getValue();
            txt += '&nbsp;<i class="fa fa-angle-right"></i><i class="fa fa-angle-right"></i><i class="fa fa-angle-right"></i>&nbsp;'
            txt += field["dst_ip"].getValue();
            if (!field["dst_port"].isEmpty) {
                txt += ':' + field["dst_port"].getValue();
            }
            if (!field["nat_dst_ip"].isEmpty) {
                txt += '(NATed: ' + field["nat_dst_ip"].getValue();
                if (!field["nat_dst_port"].isEmpty) {
                    txt += ':' + field["nat_dst_port"].getValue();
                }
                txt += ')'
            }
            txt += '</div></div>';
        }
        this.message += txt;
    }
    OneLineResult.prototype.Show = function () {
        console.info("*Show Result");
        $('#one-result').prepend(this.message);
    };
    OneLineResult.prototype.Del = function (n) {
        $('.close')[n].click();
    };
}

/**
 *  @class OneLineのフォームを操作する関数
 */
var OneLineForm = function () {
    /**
     * 各フォームを無効化する関数
     */
    OneLineForm.prototype.Disable = function () {
        $("#content-one-line .form-group select").attr("disabled", "disabled");//select box
        $("#content-one-line .form-group input").attr("disabled", "disabled");//input form
        $("#content-one-line .box-footer button").attr("disabled", "disabled");//reset,run
    }
    /**
     * 各フォームを有効化する関数
     */
    OneLineForm.prototype.Enable = function () {
        $("#content-one-line .form-group select").removeAttr("disabled", "disabled");//select box
        $("#content-one-line .form-group input").removeAttr("disabled", "disabled");//input form
        $("#content-one-line .box-footer button").removeAttr("disabled", "disabled");//reset,run
    }
    /**
     * onelineのエラーモーダルを表示する関数
     * @param {string}error_msg バリデーション結果のエラー文字列
     */
    OneLineForm.prototype.ShowError = function (error_msg) {
        $('#modal-oneline-param-invalid-errors').html(error_msg);
        $('#modal-oneline-param-invalid').css('display', 'block');
    }
    /**
     * onelineのスピナーを止める関数
     */
    OneLineForm.prototype.StopSpinner = function () {
        $('#one-spinner').css('display', 'none');
    }
    /**
     * onelineのエラーモーダルの中身を消す関数
     */
    OneLineForm.prototype.ClearModal = function (){
        $('#modal-oneline-param-invalid-errors').html('');
    }
}


// One-Lineクリック時
$(".sidebar-one-line").click(function () {
    $('.content-wrapper').css('display', 'none');
    $('#content-one-line').css('display', 'block');
    $('.sidebar-menu li').removeClass('active');
    $('.sidebar-menu #menu-one-line').addClass('active');
    if (isScenarioEmpty()) {//scenarioのcsvインポート中はApplyできない。
        $('#one-run').removeAttr('disabled', 'disabled');
    }
});

$("#one-run").click(function () {
    if (needle === null) {
        $('#modal-oneline-unreachable').css('display', 'block');
        $('#modal-oneline-unreachable-close').focus();
    } else {
        oneline.Start();
    }
});

// One-Line Resetボタン押下
$("#one-reset").click(function () {
    disabled_input_boxes();
});

// One-Lineクリック時
$(".sidebar-one-line").click(function () {
    $('.content-wrapper').css('display', 'none');
    $('#content-one-line').css('display', 'block');
    $('.sidebar-menu li').removeClass('active');
    $('.sidebar-menu #menu-one-line').addClass('active');
    if ($('#scenario-filename').val() === '') {//scenarioのcsvインポート中はApplyできない。
        $('#one-run').removeAttr('disabled', 'disabled');
    }
});

/*debug
$(".sidebar-one-line").click();
$("#one-protocol").val(3);
$("#one-srcfw").val("172.16.0.254");
$("#one-srcip").val("192.168.100.1/24");
$("#one-srcport").val("1");
$("#one-dstfw").val("10.0.0.254");
$("#one-dstip").val("1.1.1.1/24");
$("#one-dstport").val("80");
$("#one-nat-dstip").val("");
$("#one-nat-dstport").val("");
*/
