'use strict'

/**
 *
 *  @class Fileアップロードクラス。
 *  @classdesc File upload class
 *
 */
var FileUpload = function() {
    /*
    * 送信対象のファイル
    * @property object
    **/
    this.file = {};
    this.isInvalid = false;
    this.url = "";
    this.isUpdater = false;
    this.binaryType = "";
    this.errMessages = [];
    this.currentVer = {};

    const REQUEST_URL = {
         "newneedlework": 'http://192.0.2.1:8082/2/update/'
        ,"newupdater": 'http://192.0.2.1:8080/1/newupdater/'
    }

    /**
    * ファイル情報をフィールドにセットする
    * @param elem {Jquery object}
    **/
    FileUpload.prototype.SetFile = function(elem) {
        this.SetBinaryType(elem.attr('id'));
        this.file[this.GetBinaryType()] = elem.prop('files')[0];
        this.ValidateFile();
    }
    /**
    * アップロード対象のファイルを取得する
    * @return file {File}
    **/
    FileUpload.prototype.GetFile = function() {
        return this.file[this.GetBinaryType()];
    }
    /**
    * 本体バイナリ、アップデータのいずれかのFileを削除する。
    * @property binaryType {string}
    **/
    FileUpload.prototype.DeleteFile = function() {
        delete this.file[this.GetBinaryType()];
    }
    /**
    * ファイル名を取得
    * @return filename {string}
    **/
    FileUpload.prototype.GetFileName = function() {
        return this.file[this.GetBinaryType()].name;
    }
    /**
    * ファイルパスを取得
    * @return filepath {string}
    **/
    FileUpload.prototype.GetFilePath = function() {
        return this.file[this.GetBinaryType()].path;
    }
    /**
    * ファイルサイズを取得
    * @return filesize {integer}
    **/
    FileUpload.prototype.GetFileSize = function() {
        return this.file[this.GetBinaryType()].size;
    }
    /**
    * コンテントタイプを取得
    * @return filetype {string}
    **/
    FileUpload.prototype.GetFileType = function() {
        return this.file[this.GetBinaryType()].type;
    }
    /**
    * バイナリの種類（本体、アップデータ）を格納
    * @property binaryType {string}
    **/
    FileUpload.prototype.SetBinaryType = function(binaryType) {
        this.binaryType = binaryType;
    }
    /**
    * バイナリの種類（本体、アップデータ）の取得
    * @return binaryType {string}
    **/
    FileUpload.prototype.GetBinaryType = function() {
        return this.binaryType;
    }
    /**
    * エラーフラグのセット
    * @property bool {bool}
    */
    FileUpload.prototype.SetIsInvalid = function(bool) {
        this.isInvalid = bool;
    }
    /**
    * エラーフラグの取得
    * @return isInvalid {bool}
    **/
    FileUpload.prototype.GetIsInvalid = function() {
        return this.isInvalid;
    }
    /**
    * 現在のバージョンを格納
    * @param version {int}
    * @param binayType {string}
    **/
    FileUpload.prototype.SetCurrentVer = function(version, binaryType) {
        this.currentVer[binaryType] = version
    }
    /**
    * 現在のバージョンを取得
    * @return currentVer {string}
    **/
    FileUpload.prototype.GetCurrentVer = function() {
        return this.currentVer[this.GetBinaryType()]
    }

    /**
    * ファイルの正当性のチェック
    **/
    FileUpload.prototype.ValidateFile = function() {
        let type = this.GetFileType();
        if (type !== 'application/zip' && type !== 'application/x-zip-compressed') {
            this.SetIsInvalid(true);
            this.errMessages.push("This file isn't ZIP file.");
        }
        let size = this.GetFileSize();
        if (size > 20000000) { // 20MB以下
            this.SetIsInvalid(true);
            this.errMessages.push("This file is too large to upload.");
        }
        if (this.isInvalid) {
            this.ShowError();
        }
        $('#' + this.binaryType).val('');
    }
    /**
    * エラーメッセージ表示
    */
    FileUpload.prototype.ShowError = function() {
        $("#modal-update-binary-invalid").css({'display': 'block'});
        let err = "";
        for (let i = 0; i < this.errMessages.length; i++) {
            err += this.errMessages[i] + "<br>";
        }
        $("#modal-update-binary-errors").html(err);
        this.errMessages = [];
    }
    /**
    * ファイルをポストする。
    **/
    FileUpload.prototype.DoUpdate = function() {
        showBigLoader();
        let prefix = (this.GetBinaryType() === 'newneedlework') ? '#nw' : '#nu';
        this.url = REQUEST_URL[this.GetBinaryType()] + this.GetCurrentVer();
        let formData = new FormData(this.GetFile());
        formData.append(this.GetBinaryType(), this.GetFile());
        let that = this;
        $.ajax({
            type: 'POST',
            url: this.url,
            dataType: 'json',
            data: formData,
            processData : false,
            contentType: false,
            cache: false
        }).then(
            function (data) { // success
                that.InitForm();
                hideBigLoader();
                let version = versionFormatter(data.Status.toString());
                $(prefix + '-update-status-msg').html('<i class="fa fa-check" style="color:#00a65a"></i> ' + data.Message.replace('%rep%', version));
                if (prefix === '#nu') {
                    $('#nw-binary-browse').removeAttr('disabled', 'disabled');
                    setTimeout(function(){
                        $('#nw-updt-update').fadeOut(300);
                    }, 1000);
                } else {
                    $('#current-version').text('Current version: ' + version);
                }
            },
            function (xhr) { // error
                that.InitForm();
                hideBigLoader();
                $(prefix + '-update-status-msg').html('<i class="fa fa-times" style="color: red;"></i> ' + xhr.responseJSON.Message);
            }
        );
    }

    /**
    * 初期化する
    **/
    FileUpload.prototype.InitForm = function() {
        let prefix = (this.binaryType === 'newneedlework') ? '#nw' : '#nu';
        $(prefix + '-form-delete').attr('disabled', 'disabled');
        $(prefix + "-upload").attr('disabled', 'disabled');
        $('#' + this.binaryType).val('');
        $(prefix + '-binary-name').val('');
        this.DeleteFile();
    }

}

// バージョン確認のサブワーカー
var worker_u = createWorkerByFunc(function() {
    onmessage = function(event) {
        var url = 'http://192.0.2.1:8080/1/newupdater';
        var xhr = new XMLHttpRequest();
        xhr.timeout = 30000;
        xhr.responseType = 'json';
        xhr.open('GET', url, false);
        xhr.onreadystatechange = function() {
            if (xhr.status == 200) {
                postMessage(xhr.response);
            } else {
                postMessage({"IsLatest": true, "Message": "Failed to connect", "Version": 100});
            }
        }
        xhr.send(null);
    }
});

// コードの文字列からブロブ、URLを生成してワーカーを作成する
function createWorkerByCode(wcode) {
    var blob = new Blob([wcode], {type: "type/javascript"});
    var url = URL.createObjectURL(blob);
    return new Worker(url);
}

// 関数を文字列変換し、createWorkerByCodeの返り値を返す
function createWorkerByFunc(workerFunc) {
  var worerCode = workerFunc.toString().trim().match(
    /^function\s*\w*\s*\([\w\s,]*\)\s*{([\w\W]*?)}$/
  )[1];
  return createWorkerByCode(worerCode);
}

// アップデータ用アップデートフォーム
function GetMessageFromWorkerU() {
    worker_u.postMessage("");
    worker_u.addEventListener('message', onmessage, false);
    let up = upload;
    worker_u.onmessage = function (event) {
        up.SetCurrentVer(event.data.Version, $('#nu-upload').data('binaryType'))
        var version = versionFormatter(event.data.Version.toString());
        $("#current-version-u").text("Current version: " + version);
        if (!event.data.IsLatest) {
            $('#nw-updt-update').addClass('disp-block');
            $('#nw-updt-update').removeClass('disp-none');
            $('#nw-binary-browse').attr('disabled', 'disabled');
            $('#nu-binary-browse').removeAttr('disabled', 'disabled');
        } else {
            $('#nw-updt-update').removeClass('disp-block');
            $('#nw-updt-update').addClass('disp-none');
            $('#nw-binary-browse').removeAttr('disabled', 'disabled');
            $('#nu-binary-browse').attr('disabled', 'disabled');
        }
        if (!isScenarioEmpty()) {
            $('#nw-binary-browse').attr('disabled', 'disabled');
            $('#nu-binary-browse').attr('disabled', 'disabled');
        }
    }
}

function set_current_version() {
    GetMessageFromWorkerU()
    let up = upload;
    $.ajax({
        type: 'GET',
        url: 'http://192.0.2.1:8080/version',
        dataType: 'json',
        timeout: 30000,
    }).then(
        function(data) {
            up.SetCurrentVer(data.Version, $('#nw-upload').data('binaryType'))
            var datastr = data.Version.toFixed();
            var version = versionFormatter(datastr);
            $("#current-version").text("Current version: " + version);
        },
        function(xhr) {
            console.info("connect error");
        }
        )
}

function versionFormatter(number) {
    var version = "";
    for (var i = 0; i < number.length; i++) {
        var dot = "";
        if (i > 0) {
            dot = ".";
        }
        version += dot + number.charAt(i);
    }
    return version;
}

// イベント

// One-Line Resetボタン押下
$("#one-reset").click(function() {
    disabled_input_boxes();
});

// パラメータ異常を示すモーダルを閉じる時
$('#modal-oneline-param-invalid-close').click(function() {
    $('#modal-oneline-param-invalid').css('display', 'none');
});
// NeedleWork本体との通信が取れないモーダルを閉じる時(oneline)
$('#modal-oneline-unreachable-close').click(function() {
    $('#modal-oneline-unreachable').css('display', 'none');
});

function disabled_input_boxes() {
    $('#one-protocol').val('1');
    $('#one-srcfw').val('');
    $('#one-srcip').val('');
    $('#one-srcport').val('');
    $('#one-dstfw').val('');
    $('#one-dstip').val('');
    $('#one-dstport').val('');
    $('#one-nat-dstip').val('');
    $('#one-nat-dstport').val('');
}

// Updateクリック時
$(".sidebar-update").click(function() {
    $('.content-wrapper').css('display', 'none');
    $('#content-update').css('display', 'block');
    $('.sidebar-menu li').removeClass('active');
    $('.sidebar-menu #menu-update').addClass('active');
    set_current_version();
    $('#nw-update-status-msg').html('');
    $('#nu-update-status-msg').html('');
});


// 疑似クリック
$('#nw-binary-browse').click(function() {
    $('#newneedlework').click();
});
$('#nu-binary-browse').on('click', function() {
    $('#newupdater').click();
});

// ファイルがセットされたとき
$('#newneedlework, #newupdater').on('change', function() {
    upload.SetFile($(this));
    let prefix = ($(this).attr('id') === 'newneedlework') ? '#nw' : '#nu';
    if (!upload.GetIsInvalid()) {
        $(prefix + '-binary-name').val(upload.GetFilePath());
        $(prefix + '-upload').removeAttr('disabled', 'disabled');
        $(prefix + '-form-delete').removeAttr('disabled', 'disabled');
    } else {
        $(prefix + '-binary-name').val('');
        $(prefix + '-upload').attr('disabled', 'disabled');
        $(prefix + '-form-delete').attr('disabled', 'disabled');
    }
});
// サブミット
$('#nw-upload, #nu-upload').click(function() {
    let binaryType = $(this).data('binaryType');
    upload.SetBinaryType(binaryType);
    upload.DoUpdate();
});
// エラーモダールを閉じるとき
$('#modal-update-binary-invalid-close').click(function() {
    $("#modal-update-binary-invalid").css({'display': 'none'});
    upload.SetIsInvalid(false);
});
// クリアボタンクリック時
$('#nw-form-delete, #nu-form-delete').click(function() {
    let binaryType = $(this).data('binaryType');
    upload.SetBinaryType(binaryType);
    upload.InitForm();
});