'use strict'
/**
 *
 *  @class Vlanのメインとなるクラス。
 *  @classdesc Vlan Main
 *
 */
var Vlan = function () {
    /**
    * Vlan設定フォームクラスのインスタンス
    * @property {object}
    **/
    this.vlanForm = new VlanForm();
    /**
    * Vlanが紐づくデバイス名
    * @property {string}
    **/
    this.device = "";
    /**
    * Vlan作成・削除対象データ格納用配列
    * @property {array}
    **/
    this.vlans = [];
    /**
    * Put / Delete を区別する
    * @property {string}
    **/
    this.method = "";
    /**
    * リクエストURL
    * @property {string}
    **/
    this.requestUrl = "";
    /**
    * 送信範囲(this.Vlansのインデックス管理用)
    * @property {object}
    **/
    this.send_area = {};
    /**
    * 送信番号(個別処理時の不具合防止用)
    * @property {integer}
    **/
    this.sendNumber = 0;
    /**
    * 送信中かどうかの判別用
    * @property {string}
    **/
    this.status = "";
    /**
    * Vlanモードを選択されているデバイス名を格納
    * @property {array}
    **/
    this.modeVlan = [];
    /**
    * Validatorクラスのインスタンス
    * @property {object}
    **/
    this.validater = new Validater();
    /**
    * 値チェック判別用
    * @property {bool}
    **/
    this.isInvalid = false;

    /**
    * デバイスの設定
    * @param {String} device
    **/
    Vlan.prototype.SetDevice = function(device) {
        this.device = device;
    }
    /**
    * デバイスの取得
    * @return {string}
    **/
    Vlan.prototype.GetDevice = function() {
        return this.device;
    }
    /**
    * 作成 or 削除するVlanのデータを格納する
    * @param {number, string} arg
    **/
    Vlan.prototype.SetVlanValues = function(arg) {
        this.vlans = []; // 初期化
        let formValue = null;
        if (arg === 'all') {
            formValue = $('#vlan-' + this.GetDevice() + ' .form-wrapper:not(.disp-none)');
        } else {
            formValue = $('#vlan-' + this.GetDevice() + '-' + arg + '');
            this.SetSendNumber(arg);
        }
        if (formValue === null) {
            return;
        }
        let len = formValue.length;
        for (let i = 0; i < len; i++) {
            let obj = {
                 'vlanId': formValue.eq(i).find('.vlan-id').val()
                ,'vlanIp': formValue.eq(i).find('.vlan-ip').val()
            }
            this.Validate(arg, formValue.eq(i).find('.vlan-id').val(), formValue.eq(i).find('.vlan-ip').val(), i);
            this.vlans.push(obj);
        }
        this.SetSendArea(arg);
    }
    /**
    * switch_routed時がトリガーの場合のVlanデータ格納
    **/
    Vlan.prototype.SetVlanValuesTriggerBySwitchRouted = function() {
        this.vlans = []; // 初期化
        let json = needle.vlan;
        let settings = null;
        switch (this.GetDevice()) {
            case 'eth0':
                settings = json.Eth0;
                break;
            case 'eth1':
                settings = json.Eth1;
                break;
            case 'eth2':
                settings = json.Eth2;
                break;
            default:
                settings = json.Eth0;
                break;
        }
        if (settings == null || settings.length == 0) {
            return;
        }
        let len = settings.length;
        for (let i = 0; i < len; i++) {
            let obj = {
                 'vlanId': settings[i].Id
                ,'vlanIp': settings[i].Ip
            }
            this.Validate('all', settings[i].Id, settings[i].Ip, i);
            this.vlans.push(obj);
        }
        this.SetSendArea('all');
    }

    /**
    * 更新・追加・削除対象のVALNデータを取得する。
    * @return {object}
    **/
    Vlan.prototype.GetVlanValues = function() {
        return this.vlans;
    }
    /**
    * 送信範囲をセットする
    * @param {string, int} arg
    **/
    Vlan.prototype.SetSendArea = function(arg) {
        this.send_area.begin = 0;
        if (arg === 'all') {
            this.send_area.end = this.GetVlanValues().length - 1;
        } else {
            this.send_area.end = 0;
        }
    }
    /**
    * 送信開始の数値取得
    * @return {string}
    **/
    Vlan.prototype.GetSendBegin = function() {
        return this.send_area.begin;
    }
    /**
    * 送信終了の数値取得
    * @return {int}
    **/
    Vlan.prototype.GetSendEnd = function() {
        return this.send_area.end;
    }
    /**
    * 送信開始数のインクリメント
    **/
    Vlan.prototype.SendBeginPlus = function() {
        ++this.send_area.begin;
    }
    /**
    * メソッドをセットする
    * @param {string} method
    **/
    Vlan.prototype.SetMethod = function(method) {
        this.method = method;
    }
    /**
    * メソッドを取得
    * @return {string}
    **/
    Vlan.prototype.GetMethod = function() {
        return this.method;
    }
    /**
    * リクエストURLをセットする
    * @param {int} vid
    * @param {string} vid
    **/
    Vlan.prototype.SetUrl = function(vid, ip) {
        let paramObj = {
             'vid': vid
            ,'ip': ip
            ,'no': this.GetSendNumber()
        }
        let parameter = $.param(paramObj)
        this.requestUrl = (vid === null && ip === null) ? 'http://192.0.2.1:8080/1/setting/' : 'http://192.0.2.1:8080/1/setting/vlan/' + this.device + '?' + parameter;
    }
    /**
    * リクエストURLを取得
    * @return {string}
    **/
    Vlan.prototype.GetUｒｌ = function() {
        return this.requestUrl;
    }
    /**
    * 送信対象の番号をセットする
    * @param {int} num
    **/
    Vlan.prototype.SetSendNumber = function(num) {
        this.sendNumber = num;
    }
    /**
    * 送信対象の番号を取得する。
    * @return {int}
    **/
    Vlan.prototype.GetSendNumber = function() {
        return this.sendNumber;
    }
    /**
    * 送信番号のインクリメント
    **/
    Vlan.prototype.SendNumberPlus = function() {
        this.sendNumber++;
    }
    /**
    * （送信）ステータスをセットする
    * @param {string} status
    **/
    Vlan.prototype.SetStatus = function(status) {
        this.status = status;
    }
    /**
    * ステータス（送信中か否か）を取得する
    * @return {string}: sending or ''
    **/
    Vlan.prototype.GetStatus = function() {
        return this.status;
    }
    /**
    * Vlanモードのデバイス名を格納する
    * @param {string} device
    */
    Vlan.prototype.SetModeVlan = function(device) {
        let len = this.modeVlan.length;
        for (let i = 0; i < len ; i++) {
            if (this.modeVlan[i] === device) {
                return;
            }
        }
        this.modeVlan.push(device);
    }
    /**
    * Vlanモードのデバイス名一覧を取得する
    * @return {array}
    */
    Vlan.prototype.GetModeVlan = function() {
        return this.modeVlan;
    }
    /**
    * Vlanモードのデバイス名を除去する
    * @param {string} status
    **/
    Vlan.prototype.RemoveModeVlan = function(device) {
        let len = this.modeVlan.length;
        if (len === 0) { return; }
        for (let i = 0; i < len; i++) {
            if ( this.modeVlan[i] === device) {
                this.modeVlan.splice(i, 1);
            }
        }
    }
    /**
    * バリデートパスフラグのセット
    * @params {bool} bool
    **/
    Vlan.prototype.SetIsInValid = function(bool) {
        this.isInvalid = bool;
    }
    /**
    * バリデートパスフラグのセット
    * @return {bool} bool
    **/
    Vlan.prototype.GetIsInvalid = function() {
        return this.isInvalid;
    }
    /**
    * Vlanの設定取得
    **/
    Vlan.prototype.GetSetting = function() {
        showBigLoader();
        this.vlanForm.InitForm();
        this.SetMethod('GET');
        this.SetUrl(null, null);
        this.vlanForm.DisabledForm();
        let that = this;
        this.Send().then(function(data){
            setTimeout(function(){
                if (that.vlanForm.LoadSetting(data.Vlans.Eth0, 'eth0')) {
                    that.SetModeVlan('eth0');
                }
                if (that.vlanForm.LoadSetting(data.Vlans.Eth1, 'eth1')) {
                    that.SetModeVlan('eth1');
                }
                if (that.vlanForm.LoadSetting(data.Vlans.Eth2, 'eth2')) {
                    that.SetModeVlan('eth2');
                }
                if (isScenarioEmpty()) {
                    that.vlanForm.EnabledForm(that.GetModeVlan());
                }
                that.vlanForm.RemoveLoader();
            }, 500);
        },
        function(xhr){
            setTimeout(function() {
                that.vlanForm.AddFailer();
            })
        })
    }
    /**
    * Vlanの設定フォームを追加する
    **/
    Vlan.prototype.AddForms = function() {
        this.vlanForm.AddForms(this.GetDevice());
    }
    /**
    * Vlanの設定フォームの非表示
    **/
    Vlan.prototype.RemoveForms = function() {
        this.vlanForm.RemoveForms(this.GetDevice());
    }
    /**
    * Vlanを作成する
    **/
    Vlan.prototype.CreateVlan = function() {
        showBigLoader();
        this.SetMethod('PUT');
        if (!this.GetIsInvalid() && this.GetVlanValues().length > 0) {
            this.SendVlan();
        } else {
            this.Init();
        }
    }
    /**
    * Vlanを削除する
    + @return {bool}
    **/
    Vlan.prototype.DeleteVlan = function() {
        showBigLoader();
        this.SetMethod('DELETE');
        if (!this.GetIsInvalid() && this.GetVlanValues().length > 0) {
            this.SendVlan();
            return true;
        } else {
            this.Init();
            return false;
        }
    }
    /**
    * 送信処理
    **/
    Vlan.prototype.SendVlan = function() {
        this.SetStatus('sending');
        this.SetUrl(this.vlans[this.GetSendBegin()].vlanId, this.vlans[this.GetSendBegin()].vlanIp);
        let statusElement = $('#vlan-' + this.GetDevice() + '-' + this.GetSendNumber() + ' .vlan-setting-status');
        statusElement.html('<i class="fa fa-spinner fa-pulse"></i>');
        this.vlanForm.DisabledForm();
        let that = this;
        this.Send().then(
            function() { // success
                statusElement.html('<i class="fa fa-check" style="color:#00a65a"></i>');
                if (that.GetMethod() === 'DELETE') {that.ClearVlanValue()}
                if (that.GetSendBegin() === that.GetSendEnd()) { that.Init(); return; }
                else { that.Next(); }
            },
            function(err) { // error
                statusElement.html('<i class="fa fa-times" style="color: red;"></i>');
                that.ShowErrorMessage(err);
                if (that.GetSendBegin() === that.GetSendEnd()) { that.Init(); return; }
                else { that.Next(); }
            }
        );
    }
    /**
    * 次の送信を行う。
    **/
    Vlan.prototype.Next = function() {
        this.SendBeginPlus();
        this.SendNumberPlus();
        this.SendVlan();
    }
    /**
    * 処理完了時のエラー表示
    **/
    Vlan.prototype.ShowErrorMessage = function(err) {
        if (!err.responseJSON) {
            return;
        }
        let element = $('#vlan-' + this.GetDevice() + '-' + this.GetSendNumber());
        let message = err.responseJSON.Message;
        let messageHtml = '<i class="fa fa-times-circle"></i> ' + message;
        if (message.indexOf('Vlan ID') !== -1) {
            element.find('.vlan-id-setting-msg').html(messageHtml);
        } else {
            element.find('.vlan-ip-setting-msg').html(messageHtml);
        }
    }
    /**
    * delete完了時の処理
    **/
    Vlan.prototype.ClearVlanValue = function() {
        this.vlanForm.ClearVlanValue(this.GetDevice(), this.GetSendNumber());
    }
    /**
    * 処理終了時の処理
    **/
    Vlan.prototype.Init = function() {
        this.device = "";
        this.vlans = [];
        this.method = "";
        this.requestUrl = "";
        this.send_area = {};
        this.sendNumber = 0;
        this.vlanForm.EnabledForm(this.GetModeVlan());
        this.SetStatus('');
        this.isInvalid = false;
        hideBigLoader();
    }
    /**
    * バリデート処理
    **/
    Vlan.prototype.Validate = function(arg, id, ip, num) {
        let format = '<i class="fa fa-times-circle"></i> Invalid %REPLACE% is not available.';
        let format2 = '<i class="fa fa-times-circle"></i> Duplicate %REPLACE% can not be set.';
        let target = (arg === 'all') ? num : this.GetSendNumber(); // 一括（登録・削除）か否かで指定する数値が違う
        $('#vlan-' + this.device + '-' + target + ' .vlan-id').next().html('');
        $('#vlan-' + this.device + '-' + target + ' .vlan-ip').next().html('');
        if (this.CheckDuplicateVid(id)) {
            $('#vlan-' + this.device + '-' + target + ' .vlan-id').next().html(format2.replace('%REPLACE%', 'Vlan Id'));
            this.SetIsInValid(true);
        }
        if (!this.ValidateVid(id)) {
            $('#vlan-' + this.device + '-' + target + ' .vlan-id').next().html(format.replace('%REPLACE%', 'Vlan Id'));
            this.SetIsInValid(true);
        }
        if (this.CheckDuplicateIp(ip)) {
            $('#vlan-' + this.device + '-' + target + ' .vlan-ip').next().html(format2.replace('%REPLACE%', 'IP address'));
            this.SetIsInValid(true);
        }
        if (!this.ValidateIp(ip)) {
            $('#vlan-' + this.device + '-' + target + ' .vlan-ip').next().html(format.replace('%REPLACE%', 'IP address'));
            this.SetIsInValid(true);
        }
    }
    /**
    * Ipアドレスのバリデート
    * @param {string} ip
    **/
    Vlan.prototype.ValidateIp = function(ip) {
        return this.validater.Cidr(ip);
    }
    /**
    * ipアドレスの重複チェック
    * @param {string} ip
    **/
    Vlan.prototype.CheckDuplicateIp = function(ip) {
        if (ip === "") {return;}
        let vips = $('.vlan-ip');
        let len = vips.length;
        let count = 0;
        let isDuplicate = false;
        for (let i = 0; i < len; i++) {
            if (ip.split('/')[0] == vips.eq(i).val().split('/')[0]) {
                count++;
            }
        }
        for (let key in needle) {
            if (!key.match(/^eth\d$/)) { continue; }
            if (ip.split('/')[0] === needle[key]) {
                count++;
            }
        }
        if (count > 1) {
            isDuplicate = true;
        }
        return isDuplicate;
    }
    /**
    * VlanIdのバリデート
    * @param {int} id
    **/
    Vlan.prototype.ValidateVid = function(id) {
        return this.validater.VlanId(id);
    }
    /**
    * vlanIdの重複チェック
    * @param {int} id
    **/
    Vlan.prototype.CheckDuplicateVid = function(id) {
        if (id === "") {return;}
        let vids = $('.vlan-id');
        let len = vids.length;
        let count = 0;
        let isDuplicate = false;
        for (let i = 0; i < len; i++) {
            if (id === vids.eq(i).val()) {
                count++;
            }
            if (count > 1) {
                isDuplicate = true;
                break;
            }
        }
        return isDuplicate;
    }
    /**
     * データを送信する関数
     * @return {string} 通信結果
     */
    Vlan.prototype.Send = function () {
        return $.ajax({
            type: this.GetMethod(),
            url: this.GetUｒｌ(),
            dataType: 'json',
            timeout: 30000,
        })
    }
}
/**
*  @class Vlan設定フォーム関連クラス
*  @classDesc class for Vlan Setting form
*
*/
var VlanForm = function () {
    this.settings = null;
    /**
    * Vlan設定画面初期化関数
    */
    VlanForm.prototype.InitForm = function() {
        $('#vlan-eth0 .form-wrapper').not('#vlan-eth0-0').remove();
        $('#vlan-eth1 .form-wrapper').not('#vlan-eth1-0').remove();
        $('#vlan-eth2 .form-wrapper').not('#vlan-eth2-0').remove();
        $('#content-vlan .form-control').val('');
        $('.hide-form').attr('disabled', 'disabled');
        $('.vlan-setting-status i').remove();
    }
    /**
    * Vlan設定をもとにフォームを生成
    * @param {json} vlans
    * @param {string} device
    * @return {bool}
    */
    VlanForm.prototype.LoadSetting = function(vlans, device) {
        vlans = this.SortByNo(vlans);
        let isVlanMode = false;
        if (vlans == null) { return; }
        let len = vlans.length;
        if (len === 0) { return; }
        let max = parseInt(vlans[len - 1].No) + 1;
        for (let i = 0; i < max; i++) {
            let element;
            if (i === 0) {
                element = $('#vlan-' + device + '-0');
            } else {
                element = this.AddForms(device);
            }
            for (let j = 0; j < len; j++) {
                if (i === parseInt(vlans[j].No)) {
                    element.find('.vlan-id').val(vlans[j].Id);
                    element.find('.vlan-ip').val(vlans[j].Ip);
                    element.find('.short')[0].dataset.vlanNum = vlans[j].No;
                }
            }
        }
        return isVlanMode = true;
    }

    /**
    * @param {object}
    * @return {object}
    **/
    VlanForm.prototype.SortByNo = function(object) {
        if (object === null) {
            return object;
        }
        let sortObj = object.sort(function(a, b){
            if (parseInt(a.No) < parseInt(b.No)){
                return -1;
            }
            return 1;
        });

        return sortObj;
    }
    /**
    * Vlanの設定フォームを追加する
    * @param {string} device
    * @return {object} newElement
    */
    VlanForm.prototype.AddForms = function(device) {
        let selector = '#vlan-' + device;
        let last = $(selector + ' .form-wrapper').not('.disp-none').length - 1;
        let newId = last + 1;
        let newElement = null;
        if ($(selector + '-' + newId).length > 0) {
            // すでにフォームが作られている場合は非表示クラスを外す
            $(selector + '-' + newId).removeClass('disp-none');
            newElement = $(selector + '-' + newId);
        } else {
            // フォームが存在しない場合はクローンして追加する
            let clone = $(selector + '-' + last).clone();
            clone.attr('id', 'vlan-' + device + '-' + newId);
            clone.find('.form-control').each(function() {
                $(this).val('');
            });
            clone.find('.minimun span').text(newId + 1);
            clone.find('.short')[0].dataset.vlanNum = newId;
            clone.find('.vlan-setting-status i').remove();
            clone.find('.vlan-id-setting-msg').text('');
            clone.find('.vlan-ip-setting-msg').text('');
            clone.appendTo(selector + ' .box-body');
            newElement = clone;
        }
        $(selector + ' .hide-form').removeAttr('disabled', 'disabled');
        return newElement;
    };
    /**
    * Vlanの設定フォームを非表示にする
    * @param {string} device
    */
    VlanForm.prototype.RemoveForms = function(device) {
        let selector = '#vlan-' + device;
        let last = $(selector + ' .form-wrapper').not('.disp-none').length - 1;
        $(selector + '-' + last).addClass('disp-none');
        let prevId = last - 1;
        if (prevId === 0) {
            $(selector + ' .hide-form').attr('disabled', 'disabled');
        }
    };
    /**
    * すべてのフォームパーツをdisabledにする
    */
    VlanForm.prototype.DisabledForm = function() {
        $('#content-vlan input').attr('disabled', 'disabled');
        $('#content-vlan button').not('#reload_vlan_setting').attr('disabled', 'disabled');
    }
    /**
    * 一部を除くフォームパーツのdisabledを解除する
    * @param {array} modes
    */
    VlanForm.prototype.EnabledForm = function(modes) {
        let len = modes.length;
        if (len === 0) { return }
        for (let i = 0; i < len; i++) {
            this.EnabledFormByDevice(modes[i]);
        }
    }
    /**
    * device毎にフォームをdisabledにする
    * @param {string} device
    **/
    VlanForm.prototype.DisabledFormByDevice = function(device) {
        $('#vlan-' + device + ' .form-wrapper button').attr('disabled', 'disabled');
        $('#vlan-' + device + ' .form-wrapper input').attr('disabled', 'disabled');
    }
    /**
    * device毎にフォームのdisabledを解除する
    * @param {string} device
    **/
    VlanForm.prototype.EnabledFormByDevice = function(device) {
        $('#vlan-' + device + ' input').removeAttr('disabled', 'disabled');
        let form = $('#vlan-' + device + ' .form-wrapper').not('.disp-none');
        if (form.length == 1) {
            $('#vlan-' + device + ' button').not('.hide-form').removeAttr('disabled', 'disabled');
        } else {
            $('#vlan-' + device + ' button').removeAttr('disabled', 'disabled');
        }
    }
    /**
    * 失敗表示
    **/
    VlanForm.prototype.AddFailer = function() {
        $('#vlan-eth0-0 .vlan-setting-status').html('<i class="fa fa-times" style="color: red;"></i>');
        $('#vlan-eth1-0 .vlan-setting-status').html('<i class="fa fa-times" style="color: red;"></i>');
        $('#vlan-eth2-0 .vlan-setting-status').html('<i class="fa fa-times" style="color: red;"></i>');
        hideBigLoader();
    }
    /**
    * ローダー非表示
    **/
    VlanForm.prototype.RemoveLoader = function() {
        $('#vlan-eth0-0 .vlan-setting-status').html('');
        $('#vlan-eth1-0 .vlan-setting-status').html('');
        $('#vlan-eth2-0 .vlan-setting-status').html('');
        hideBigLoader();
    }
    /**
    * delete完了時の処理
    **/
    VlanForm.prototype.ClearVlanValue = function(device, number) {
        $('#vlan-' + device + '-' + number).find('.vlan-id').val('');
        $('#vlan-' + device + '-' + number).find('.vlan-ip').val('');
    }
}

// Event Listening
// フォーム追加ボタンクリック
$(document).on('click', '.add-form', function() {
    vlan.SetDevice($(this).parent().data('ethType'));
    vlan.AddForms();
});
// フォーム非表示ボタンクリック
$(document).on('click', '.hide-form', function() {
    vlan.SetDevice($(this).parent().data('ethType'));
    vlan.RemoveForms();
});
// All Applyボタンクリック
$(document).on('click', '.all-apply', function() {
    vlan.SetDevice($(this).parent().data('ethType'));
    vlan.SetVlanValues('all');
    vlan.CreateVlan();
});
// Applyボタンクリック
$(document).on('click', '.apply', function() {
    vlan.SetDevice($(this).parent().data('ethType'));
    vlan.SetVlanValues($(this).parent().data('vlanNum'));
    vlan.CreateVlan();
});
// All Removeボタンクリック
$(document).on('click', '.all-remove', function() {
    vlan.SetDevice($(this).parent().data('ethType'));
    vlan.SetVlanValues('all');
    if (!vlan.GetIsInvalid()) {
        $('#modal-vlan-remove').css('display', ' block');
    } else {
        vlan.SetIsInValid(false);
    }
});
// Removeボタンクリック
$(document).on('click', '.remove', function() {
    vlan.SetDevice($(this).parent().data('ethType'));
    vlan.SetVlanValues($(this).parent().data('vlanNum'));
    if (!vlan.GetIsInvalid()) {
        $('#modal-vlan-remove').css('display', ' block');
    } else {
        vlan.SetIsInValid(false);
    }
});
// Remove時アラートのcontinueボタンクリック
$(document).on('click', '#modal-vlan-remove-continue', function() {
    vlan.DeleteVlan();
    $('#modal-vlan-remove').css({'display': 'none'});
});
/**
* VlanIdのフォームからフォーカスが外れたとき
**/
/*$(document).on('blur', '.vlan-id', function(){
    let isPass = vlan.ValidateVid($(this).val());
    if (!isPass) {
        $(this).next().html('<i class="fa fa-times-circle"></i> Invalid Vlan ID is not available.');
    } else {
        $(this).next().html('');
    }
});*/
/**
* Ipアドレスのフォームからフォーカスが外れたとき
**/
/*$(document).on('blur', '.vlan-ip', function(){
    let isPass = vlan.ValidateIp($(this).val());
    if (!isPass) {
        $(this).next().html('<i class="fa fa-times-circle"></i> Invalid IP address is not available.');
    } else {
        $(this).next().html('');
    }
});*/
/**
* エラーメッセージを消去
**/
$(document).on('click','.vlan-id, .vlan-ip', function(){
    $(this).next().html('');
});
/**
* エラーメッセージを消去
**/
$(document).on('click', '.vlan-id-setting-msg, .vlan-ip-setting-msg', function(){
    $(this).html('');
});
// Vlanメニュー、リローボタンクリック時
$(".sidebar-vlan, #reload_vlan_setting").click(function() {
    $('.content-wrapper').css('display', 'none');
    $('#content-vlan').css('display', 'block');
    $('.sidebar-menu li').removeClass('active');
    $('.sidebar-menu #menu-vlan').addClass('active');
    $('.vlan-id-setting-msg').text('');
    $('.vlan-ip-setting-msg').text('');
    vlan.GetSetting();
});